
XEP-0059: Result Set Management
===============================

.. module:: slixmpp.plugins.xep_0059

.. autoclass:: XEP_0059
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end

.. autoclass:: ResultIterator
    :members:
    :member-order: bysource

Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0059.stanza
    :members:
    :undoc-members:

